- `Absolute vs. explicit relative import of Python module  <https://stackoverflow.com/a/16748366/2519059>`_
- `Withdraw anti-recommendation of relative imports from documentation <https://bugs.python.org/msg118031>`_
